/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.component.sensor.location;

/**
 * Interface for an attraction point (basically a named location)
 * 
 * @author Bjoern Richerzhagen
 *
 */
public interface IAttractionPoint extends Location {

	/**
	 * Name of the attraction point
	 * 
	 * @return
	 */
	public String getName();

	/**
	 * Clones the current attraction point and manipulates the new AP's name.
	 * The location of the new AP can then be manipulated through the
	 * {@link Location} API.
	 * 
	 * @param newName
	 * @return
	 */
	public IAttractionPoint clone(String newName);

	/**
	 * A weight (should be normalized between 0 and 1), can be used for example
	 * in the social movement model. This refers to the "importance" of an
	 * {@link IAttractionPoint}.
	 * 
	 * @return weight between 0 and 1
	 */
	public default double getWeight() {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	/**
	 * A radius (optional), basically the radius of influence of the given
	 * attraction point.
	 * 
	 * @return radius in meters
	 */
	public default double getRadius() {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	/**
	 * A weight (should be normalized between 0 and 1), can be used for example
	 * in the social movement model. This refers to the "importance" of an
	 * {@link IAttractionPoint}.
	 * 
	 * @param weight
	 */
	public default void setWeight(double weight) {
		throw new UnsupportedOperationException("Default: Not implemented");
	};

	public default boolean hasWeight() {
		return false;
	}

	/**
	 * A radius (optional), basically the radius of influence of the given
	 * attraction point.
	 * 
	 * @param radius
	 */
	public default void setRadius(double radius) {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	public default boolean hasRadius() {
		return false;
	}


	/**
	 * The pause time minimum, i.e., the minimum time a node will stay around
	 * this attraction point.
	 * 
	 * @return
	 */
	public default long getPauseTimeMin() {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	/**
	 * The pause time maximum, i.e., the maximum time a node will stay around
	 * this attraction point.
	 * 
	 * @return
	 */
	public default long getPauseTimeMax() {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	public default void setPauseTime(long pauseTimeMin, long pauseTimeMax) {
		throw new UnsupportedOperationException("Default: Not implemented");
	}

	public default boolean hasPauseTime() {
		return false;
	}

}
