package de.tudarmstadt.maki.simonstrator.api.component.vehicular.api;

import java.util.List;

import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;

/**
 * 
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 06.11.2017
 *
 */
public interface EdgeController {

	/**
	 * This method is used to restrict the shown vehicles to the vehicles in a
	 * certain area.
	 * 
	 * @param pStartX
	 *            the x-start of the observed area
	 * @param pStartY
	 *            the y-start of the observed area
	 * @param pEndX
	 *            the x-end of the observed area
	 * @param pEndY
	 *            the x-end of the observed area
	 */
	void setObservedArea(double pStartX, double pStartY, double pEndX, double pEndY);

	/**
	 * Initializes the controller
	 */
	void init();

	/**
	 * set the maximum allowed edge speed, can be used for congestion etc.
	 * 
	 * @param pEdgeID
	 *            the id of the edge
	 * @param pMaxSpeed
	 *            the new maximum allowed speed
	 */
	void setEdgeMaxSpeed(String pEdgeID, double pMaxSpeed);

	/**
	 * 
	 * @param pEdgeID
	 * @return
	 */
	double getLastStepMeanSpeed(String pEdgeID);

	/**
	 * @param pEdgeID
	 * @return
	 */
	Location getEdgeMeanPosition(String pEdgeID);

	/**
	 * @return the startX
	 */
	public double getStartX();

	/**
	 * @return the startY
	 */
	public double getStartY();

	/**
	 * @return the endX
	 */
	public double getEndX();

	/**
	 * @return the endY
	 */
	public double getEndY();

	/**
	 * @return the observedAreaSet
	 */
	public boolean isObservedAreaSet();

	/**
	 * @param pLaneID
	 * @return
	 */
	List<Location> getLaneShape(String pLaneID);

	/**
	 * @param pEdgeID
	 * @return
	 */
	boolean isEdgeUsable(String pEdgeID);

	/**
	 * @param pEdgeID
	 * @return
	 */
	double getEdgeLength(String pEdgeID);
}
